@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 #include "config.h"
@@ -216,7 +215,7 @@ int AddBinding(
 					 * configuration. */
 					mask = modifier_mapindex_to_mask[m - 1];
 					if (modifiers != AnyModifier &&
-					    !(modifiers & mask) != mask)
+					    !((modifiers & mask) != mask))
 					{
 						add_modifiers = mask;
 						bind_mask = (1 << m);
